@@ -2,6 +2,7 @@ import argparse
 import asyncio
 import json
 
+from ._version import __version__
 from bscpylgtv import WebOsClient
 
 
@@ -11,8 +12,8 @@ async def list_keys(path_key_file):
     await storage.list_keys()
 
 async def runloop(args):
-    client = await WebOsClient.create(args.host, ping_interval=None, states=args.states,
-        client_key=args.key, key_file_path=args.path_key_file)
+    client = await WebOsClient.create(args.host, ping_interval=None, get_hello_info=args.get_hello_info,
+        states=args.states, client_key=args.key, key_file_path=args.path_key_file)
     await client.connect()
     print(await getattr(client, args.command)(*args.parameters))
     await client.disconnect()
@@ -40,6 +41,11 @@ def convert_arg(arg):
 
 def bscpylgtvcommand():
     parser = argparse.ArgumentParser(description="Send command to LG WebOs TV.")
+    parser.add_argument(
+        "-v", "--version",
+        action="version",
+        version=f'%(prog)s {__version__}'
+    )
     parser.add_argument(
         "-l", "--list_client_keys",
         dest="list_client_keys",
@@ -59,6 +65,12 @@ def bscpylgtvcommand():
         parser.add_argument(
             "-k", "--key", type=str, help="optional client key"
         )
+        parser.add_argument(
+            "-o", "--get_hello_info",
+            dest="get_hello_info",
+            action="store_true",
+            help="optional getting hello info (e.g. to get unique deviceUUID)"
+        )
         parser.add_argument(
             "-s", "--set_states",
             dest="states",
